# Mr. Estimator Example Script

Instead of downloading the `data.zip` and extracting,
you can grab the two scripts and run: ```python3 create_example_data.py```

This will create the example data in the directory where `create_example_data.py` was saved.

See [Getting Started](https://mrestimator.readthedocs.io/en/latest/doc/gettingstarted.html) for more details.
